.. :changelog:

History
-------

1.1.5 (2021-05-11)
===================

* Transfer ownership to Infoxchange
* Update documentation
* Dependency upgrades


1.1.4 (2021-05-05)
===================

* Updated documentation
* Dependency upgrades


1.1.3 (2021-04-12)
===================

* Add Django 3.2 to the test matrix
* Dependency upgrades
* Minor fixes


1.1.2 (2021-02-11)
===================

* Security patch


1.1.1 (2021-02-04)
===================

* Dependency upgrades
* Security patch
* Improve returned responses


1.1.0 (2021-01-27)
===================

* Dependecy upgrades
* Add ability to index a model object into multiple app search engines


1.0.2 (2020-12-29)
===================

* Dependency upgrades


1.0.1 (2020-12-15)
===================

* Dependency upgrades


1.0.0 (2020-11-26)
===================

* Python 3.9 support
* Update the project status to stable


0.7.6 (2020-11-26)
===================

* Dependency upgrades
* Update documentation


0.7.5 (2020-10-28)
===================

* Security patch


0.7.4 (2020-10-05)
===================

* Add support for testing overridden queryset methods
* Update documentation


0.7.3 (2020-08-25)
===================

* Remove support for Django 2.0 and Django 2.1
* Add support for Django 3.1
* Update documentation


0.7.2 (2020-08-25)
===================

* Dependency upgrades


0.7.1 (2020-07-31)
===================

* Dependency upgrades


0.7.0 (2020-07-30)
===================

* Implement ability to do partial updates to documents
* Dependency upgrades


0.6.11 (2020-06-22)
===================

* Fix failing dependency check with pipenv
* Dependency upgrades


0.6.9 (2020-05-15)
==================

* Dependency upgrades


0.6.8 (2020-03-31)
==================

* Dependency upgrades
* Security patches


0.6.7 (2020-02-25)
==================

* Dependency upgrades


0.6.6 (2020-02-01)
==================

* Dependency upgrades


0.6.3 (2020-01-03)
==================

* Move from Travis CI to Github Actions
* Documentation updates


0.6.2 (2020-01-02)
==================

* Dependency upgrades
* Documentation improvements
* Add linting for CI
* Setup automatic PyPI releases


0.6.1 (2019-12-24)
==================

* Dependency upgrades


0.6.0 (2019-12-04)
==================

* Remove support for Python 3.5
* Add support for Python 3.8
* Add support for Django 3
* Dependency upgrades
* Bump development status to Beta


0.5.6 (2019-12-03)
==================

* Dependency upgrades


0.5.5 (2019-11-14)
==================

* Dependency upgrades


0.5.4 (2019-10-02)
==================

* Dependency upgrades


0.5.3 (2019-08-28)
==================

* Improve documentation
* Refactor settings name ``APPSEARCH_URL`` -> ``APPSEARCH_HOST``


0.5.1 (2019-08-26)
==================

* Improve test coverage
* Improve documentation
* Add serpy as an official dependency
* Bump dependency versions
* Add code of conduct


0.4.2 (2019-08-16)
==================

* Switch to the new official Elastic App Search python client
* Documentation improvements


0.2.3 (2019-08-02)
==================

* Use Pipenv for dependency management
* Configure Dependabot for automatic dependency upgrades
* Remove support for Python 3.4
* Documentation improvements


0.2.2 (2019-07-29)
==================

* Bug fixes
* Documentation improvements


0.1.0 (2019-07-26)
==================

* First release on PyPI.
